cocos.audio.pygame package — cocos v0.6.5 documentation

# cocos.audio.pygame package

## Submodules

- cocos.audio.pygame.base module
- cocos.audio.pygame.mixer module
- cocos.audio.pygame.music module
- cocos.audio.pygame.version module

## Module contents

Top-level Pygame module.

Pygame is a set of Python modules designed for writing games. It is written on top of the excellent SDL library. This allows you to create fully featured games and multimedia programs in the Python language. The package is highly portable, with games running on Windows, MacOS, OS X, BeOS, FreeBSD, IRIX, and Linux.

class `MissingModule`(name, info='', urgent=0)

  Bases: `object`

  `warn`()